==> cxf-testutils-2.0.6.16-fuse-sources.jar: org/apache/type_test/types2/OccuringStructWithAnyAttribute.java <==

package org.apache.type_test.types2;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAnyAttribute;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElements;
import javax.xml.bind.annotation.XmlType;
import javax.xml.namespace.QName;


/**
 * <p>Java class for OccuringStructWithAnyAttribute complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="OccuringStructWithAnyAttribute">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence maxOccurs="5">
 *         &lt;element name="varString" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="varInt" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *       &lt;/sequence>
 *       &lt;attribute name="AtInt" type="{http://www.w3.org/2001/XMLSchema}int" />
 *       &lt;attribute name="AtString" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "OccuringStructWithAnyAttribute", propOrder = {
    "varStringAndVarInt"
})
public class OccuringStructWithAnyAttribute {

    @XmlElements({
        @XmlElement(name = "varInt", namespace = "http://apache.org/type_test/types2", required = true, type = Integer.class),
        @XmlElement(name = "varString", namespace = "http://apache.org/type_test/types2", required = true, type = String.class)
    })
    protected List<Serializable> varStringAndVarInt;
    @XmlAttribute(name = "AtInt")
    protected Integer atInt;
    @XmlAttribute(name = "AtString")
    protected String atString;
    @XmlAnyAttribute
    private Map<QName, String> otherAttributes = new HashMap<QName, String>();

    /**
     * Gets the value of the varStringAndVarInt property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the varStringAndVarInt property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getVarStringAndVarInt().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Integer }
     * {@link String }
     * 
     * 
     */
    public List<Serializable> getVarStringAndVarInt() {
        if (varStringAndVarInt == null) {
            varStringAndVarInt = new ArrayList<Serializable>();
        }
        return this.varStringAndVarInt;
    }

    /**
     * Gets the value of the atInt property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public Integer getAtInt() {
        return atInt;
    }

    /**
     * Sets the value of the atInt property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setAtInt(Integer value) {
        this.atInt = value;
    }

    /**
     * Gets the value of the atString property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAtString() {
        return atString;
    }

    /**
     * Sets the value of the atString property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAtString(String value) {
        this.atString = value;
    }

    /**
     * Gets a map that contains attributes that aren't bound to any typed property on this class.
     * 
     * <p>
     * the map is keyed by the name of the attribute and 
     * the value is the string value of the attribute.
     * 
     * the map returned by this method is live, and you can add new attribute
     * by updating the map directly. Because of this design, there's no setter.
     * 
     * 
     * @return
     *     always non-null
     */
    public Map<QName, String> getOtherAttributes() {
        return otherAttributes;
    }

}

==> cxf-testutils-2.0.10.0-fuse-sources.jar: org/apache/type_test/types2/OccuringStructWithAnyAttribute.java <==

package org.apache.type_test.types2;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAnyAttribute;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElements;
import javax.xml.bind.annotation.XmlType;
import javax.xml.namespace.QName;


/**
 * <p>Java class for OccuringStructWithAnyAttribute complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="OccuringStructWithAnyAttribute">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence maxOccurs="5">
 *         &lt;element name="varString" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="varInt" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *       &lt;/sequence>
 *       &lt;attribute name="AtInt" type="{http://www.w3.org/2001/XMLSchema}int" />
 *       &lt;attribute name="AtString" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "OccuringStructWithAnyAttribute", propOrder = {
    "varStringAndVarInt"
})
public class OccuringStructWithAnyAttribute {

    @XmlElements({
        @XmlElement(name = "varString", namespace = "http://apache.org/type_test/types2", required = true, type = String.class),
        @XmlElement(name = "varInt", namespace = "http://apache.org/type_test/types2", required = true, type = Integer.class)
    })
    protected List<Serializable> varStringAndVarInt;
    @XmlAttribute(name = "AtInt")
    protected Integer atInt;
    @XmlAttribute(name = "AtString")
    protected String atString;
    @XmlAnyAttribute
    private Map<QName, String> otherAttributes = new HashMap<QName, String>();

    /**
     * Gets the value of the varStringAndVarInt property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the varStringAndVarInt property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getVarStringAndVarInt().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link String }
     * {@link Integer }
     * 
     * 
     */
    public List<Serializable> getVarStringAndVarInt() {
        if (varStringAndVarInt == null) {
            varStringAndVarInt = new ArrayList<Serializable>();
        }
        return this.varStringAndVarInt;
    }

    /**
     * Gets the value of the atInt property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public Integer getAtInt() {
        return atInt;
    }

    /**
     * Sets the value of the atInt property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setAtInt(Integer value) {
        this.atInt = value;
    }

    /**
     * Gets the value of the atString property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAtString() {
        return atString;
    }

    /**
     * Sets the value of the atString property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAtString(String value) {
        this.atString = value;
    }

    /**
     * Gets a map that contains attributes that aren't bound to any typed property on this class.
     * 
     * <p>
     * the map is keyed by the name of the attribute and 
     * the value is the string value of the attribute.
     * 
     * the map returned by this method is live, and you can add new attribute
     * by updating the map directly. Because of this design, there's no setter.
     * 
     * 
     * @return
     *     always non-null
     */
    public Map<QName, String> getOtherAttributes() {
        return otherAttributes;
    }

}
